@@ -4,14 +4,14 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: i18n.c,v 1.36 2008/04/14 21:22:08 phintuka Exp $
+ * $Id: i18n.c,v 1.36.2.2 2008/10/17 20:19:50 phintuka Exp $
  *
  * Translations provided by:
  *
  * Finnish   Petri Hintukainen, Rolf Ahrenberg
  * Russian   Vladimir Monchenko
  * German    Udo Richter
- * Italian   Gringo <vdr-italian@tiscali.it
+ * Italian   Diego Pierotto
  *
  */
 
@@ -1742,7 +1742,7 @@ const tI18nPhrase Phrases[] = {
     "", // Czech
   },
   { "Play DVD disc >>", // English
-    "DVD abspielen", // Deutsch
+    "DVD abspielen >>", // Deutsch
     "", // Slovenski
     "Riproduci disco DVD >>", // Italiano
     "", // Nederlands
