@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: playlist.c,v 1.17 2008/04/03 15:11:26 phelin Exp $
+ * $Id: playlist.c,v 1.17.2.1 2008/09/26 19:09:29 phintuka Exp $
  *
  */
 
@@ -873,7 +873,8 @@ bool cPlaylist::Read(const char *PlaylistFile, bool Recursive)
     if(strrchr(m_Name, '.'))
       *(strrchr(m_Name, '.')) = 0;
 
-  } else if(PlaylistFile[strlen(PlaylistFile)-1] == '/') {
+  } else if(PlaylistFile[                     0] == '/'  &&
+            PlaylistFile[strlen(PlaylistFile)-1] == '/') {
     // Scan folder
     Result = ScanFolder(PlaylistFile, Recursive) > 0;
     m_Origin = eImplicit;
