@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: xine_post_autocrop.c,v 1.12 2008/01/02 01:55:19 phintuka Exp $
+ * $Id: xine_post_autocrop.c,v 1.12.2.1 2008/09/26 13:33:28 phintuka Exp $
  *
  */
 
@@ -27,7 +27,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xine_post_autocrop.c,v 1.12 2008/01/02 01:55:19 phintuka Exp $
  *
  * autocrop video filter by Petri Hintukainen 25/03/2006
  *
@@ -1512,7 +1511,7 @@ static post_plugin_t *autocrop_open_plugin(post_class_t *class_gen,
 					    xine_video_port_t **video_target)
 {
   if (video_target && video_target[ 0 ]) {
-    autocrop_post_plugin_t *this = (autocrop_post_plugin_t*)xine_xmalloc(sizeof(autocrop_post_plugin_t));
+    autocrop_post_plugin_t *this = calloc(1, sizeof(autocrop_post_plugin_t));
     post_in_t           *input;
     post_out_t          *output;
     post_video_port_t   *port;
@@ -1594,7 +1593,7 @@ static void autocrop_class_dispose(post_class_t *class_gen)
 
 static void *autocrop_init_plugin(xine_t *xine, void *data)
 {
-  post_class_t *class = (post_class_t*)malloc(sizeof(post_class_t));
+  post_class_t *class = calloc(1, sizeof(post_class_t));
   
   if(class) {
     class->open_plugin     = autocrop_open_plugin;
